==> qtjambi-quick-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiQuick/QSGDynamicTexture_shell.h <==
#ifndef QSGDYNAMICTEXTURE_SHELL_H
#define QSGDYNAMICTEXTURE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQuick/qsgtexture.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QSGDynamicTexture_shell : public QSGDynamicTexture, public QtJambiShellInterface
{
public:
    QSGDynamicTexture_shell();
    ~QSGDynamicTexture_shell() override;

    void childEvent(QChildEvent* event0) override;
    qint64 comparisonKey() const override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool hasAlphaChannel() const override;
    bool hasMipmaps() const override;
    bool isAtlasTexture() const override;
    QRectF normalizedTextureSubRect() const override;
    QSize textureSize() const override;
    void timerEvent(QTimerEvent* event0) override;
    bool updateTexture() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSGDynamicTexture_access : public QSGDynamicTexture
{
    jlong __qt_comparisonKey(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasAlphaChannel(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasMipmaps(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_textureSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_updateTexture(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QSGDYNAMICTEXTURE_SHELL_H

==> qtjambi-quick-debuginfo-linux-x64-6.7.2.jar: sources/QtJambiQuick/QSGDynamicTexture_shell.h <==
#ifndef QSGDYNAMICTEXTURE_SHELL_H
#define QSGDYNAMICTEXTURE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qsgtexture.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QSGDynamicTexture_shell : public QSGDynamicTexture, public QtJambiShellInterface
{
public:
    QSGDynamicTexture_shell();
    ~QSGDynamicTexture_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QSGDynamicTexture_mshell;
    friend class QSGDynamicTexture_oshell;
};


class QSGDynamicTexture_mshell : public QSGDynamicTexture_shell
{
public:
    using QSGDynamicTexture_shell::QSGDynamicTexture_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QSGDynamicTexture_oshell : public QSGDynamicTexture_mshell
{
public:
    using QSGDynamicTexture_mshell::QSGDynamicTexture_mshell;
    void childEvent(QChildEvent* event0) override;
    qint64 comparisonKey() const override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool hasAlphaChannel() const override;
    bool hasMipmaps() const override;
    bool isAtlasTexture() const override;
    QRectF normalizedTextureSubRect() const override;
    QSize textureSize() const override;
    void timerEvent(QTimerEvent* event0) override;
    bool updateTexture() override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSGDynamicTexture_access : public QSGDynamicTexture
{
    jlong __qt_comparisonKey_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasAlphaChannel_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_hasMipmaps_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_textureSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_updateTexture(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QSGDYNAMICTEXTURE_SHELL_H
